@@ -1,21 +1,8 @@
 /*
-  Copyright (C) 2010 Casey Link <unnamedrambler@gmail.com>
-  Copyright (C) 2009-2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+  SPDX-FileCopyrightText: 2010 Casey Link <unnamedrambler@gmail.com>
+  SPDX-FileCopyrightText: 2009-2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "freebusyitemmodel.h"
@@ -82,12 +69,6 @@ private:
 class CalendarSupport::FreeBusyItemModelPrivate
 {
 public:
-    FreeBusyItemModelPrivate()
-        : mForceDownload(false)
-        , mRootData(nullptr)
-    {
-    }
-
     ~FreeBusyItemModelPrivate()
     {
         delete mRootData;
@@ -128,7 +109,7 @@ QVariant FreeBusyItemModel::data(const QModelIndex &index, int role) const
         return QVariant();
     }
 
-    ItemPrivateData *data = (ItemPrivateData *)index.internalPointer();
+    auto *data = (ItemPrivateData *)index.internalPointer();
 
     if (data->parent() == d->mRootData) {
         int row = index.row();
@@ -219,7 +200,7 @@ QModelIndex FreeBusyItemModel::parent(const QModelIndex &child) const
         return QModelIndex();
     }
 
-    ItemPrivateData *childData = static_cast<ItemPrivateData *>(child.internalPointer());
+    auto *childData = static_cast<ItemPrivateData *>(child.internalPointer());
     ItemPrivateData *parentData = childData->parent();
     if (parentData == d->mRootData) {
         return QModelIndex();
@@ -241,7 +222,7 @@ void FreeBusyItemModel::addItem(const FreeBusyItem::Ptr &freebusy)
     int row = d->mFreeBusyItems.size();
     beginInsertRows(QModelIndex(), row, row);
     d->mFreeBusyItems.append(freebusy);
-    ItemPrivateData *data = new ItemPrivateData(d->mRootData);
+    auto *data = new ItemPrivateData(d->mRootData);
     d->mRootData->appendChild(data);
     endInsertRows();
 
@@ -258,7 +239,7 @@ void FreeBusyItemModel::setFreeBusyPeriods(const QModelIndex &parent, const KCal
         return;
     }
 
-    ItemPrivateData *parentData = static_cast<ItemPrivateData *>(parent.internalPointer());
+    auto *parentData = static_cast<ItemPrivateData *>(parent.internalPointer());
     int fb_count = list.size();
     int childCount = parentData->childCount();
     QModelIndex first = index(0, 0, parent);
@@ -277,7 +258,7 @@ void FreeBusyItemModel::setFreeBusyPeriods(const QModelIndex &parent, const KCal
     } else if (fb_count > childCount) {
         beginInsertRows(parent, childCount, fb_count - 1);
         for (int i = childCount; i < fb_count; ++i) {
-            ItemPrivateData *childData = new ItemPrivateData(parentData);
+            auto *childData = new ItemPrivateData(parentData);
             parentData->appendChild(childData);
         }
         endInsertRows();
