@@ -1,24 +1,8 @@
 /*
-  Copyright (c) 2001,2003 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2001, 2003 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "kcalprefs.h"
@@ -55,7 +39,7 @@ public:
     Akonadi::Collection::Id mDefaultCalendarId;
 
     TagCache mTagCache;
-    QColor mDefaultCategoryColor;
+    const QColor mDefaultCategoryColor;
     QDateTime mDayBegins;
 };
 
@@ -281,7 +265,7 @@ bool KCalPrefs::thatIsMe(const QString &_email)
 void KCalPrefs::setCategoryColor(const QString &cat, const QColor &color)
 {
     Akonadi::Tag tag = d->mTagCache.getTagByName(cat);
-    Akonadi::TagAttribute *attr = tag.attribute<Akonadi::TagAttribute>(Akonadi::Tag::AddIfMissing);
+    auto *attr = tag.attribute<Akonadi::TagAttribute>(Akonadi::Tag::AddIfMissing);
     attr->setBackgroundColor(color);
     new Akonadi::TagModifyJob(tag);
 }
@@ -292,7 +276,7 @@ QColor KCalPrefs::categoryColor(const QString &cat) const
 
     if (!cat.isEmpty()) {
         const Akonadi::Tag &tag = d->mTagCache.getTagByName(cat);
-        if (Akonadi::TagAttribute *attr = tag.attribute<Akonadi::TagAttribute>()) {
+        if (const auto *attr = tag.attribute<Akonadi::TagAttribute>()) {
             color = attr->backgroundColor();
         }
     }
