@@ -1,22 +1,8 @@
 /*
-  Copyright (C) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company
+  SPDX-FileContributor: Tobias Koenig <tokoe@kde.org>
 
-  Author: Tobias Koenig <tokoe@kde.org>
-
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef CALENDARSUPPORT_INCIDENCEVIEWER_H
@@ -31,14 +17,11 @@
 
 class QAbstractItemModel;
 
-namespace Akonadi
-{
+namespace Akonadi {
 class ETMCalendar;
 }
 
-namespace CalendarSupport
-{
-
+namespace CalendarSupport {
 /**
  * @short A viewer component for incidences in Akonadi.
  *
@@ -86,7 +69,7 @@ public:
     /**
      * Destroys the incidence viewer.
      */
-    ~IncidenceViewer();
+    ~IncidenceViewer() override;
 
     /**
      * Sets the Calendar for this viewer.
@@ -97,12 +80,12 @@ public:
     /**
      * Returns the incidence that is currently displayed.
      */
-    Akonadi::Item incidence() const;
+    Q_REQUIRED_RESULT Akonadi::Item incidence() const;
 
     /**
      * Returns the active date used for the currently displayed incidence
      */
-    QDate activeDate() const;
+    Q_REQUIRED_RESULT QDate activeDate() const;
 
     /**
      * Returns the attachment model for the currently displayed incidence.
@@ -158,10 +141,8 @@ private:
     Private *const d;
 
     Q_PRIVATE_SLOT(d, void slotParentCollectionFetched(KJob *))
-    Q_PRIVATE_SLOT(d, void slotAttachmentUrlClicked(const QString &))
     //@endcond
 };
-
 }
 
 #endif
